''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''
' NAME:		check_mscs.vbs
' VERSION:	0.2
' AUTHOR:	Alexander Rudolf (alexander.rudolf@saxsys.de)
'
' COMMENT:	Script for Checking MSCS Cluster ressources
'		for use with Nagios and NSClient++
'
''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''

Option explicit
Dim strArglist
Dim strWmiQuery
Dim strResName
Dim strNodeName
Dim strResultCritical
Dim strResultWarning
Dim strResultOK
Dim strStatus
Dim arrResNames
Dim arrNodeNames
Dim objArgs
Dim objItem
Dim objWMIService
Dim colItems
Dim i

Set objArgs = WScript.Arguments

if objArgs(0) = "--help" Then
	Wscript.StdOut.WriteLine ""
	Wscript.StdOut.WriteLine "CHECK_MSCS Usage"
	Wscript.StdOut.WriteLine ""
	Wscript.StdOut.WriteLine "check_mscs.vbs RES [ressource list]"
	Wscript.StdOut.WriteLine "check_mscs.vbs NODE [node list]"
	Wscript.StdOut.WriteLine ""
	Wscript.StdOut.WriteLine vbTab & "ressource list    list of MSCS ressource names to be monitored"
	Wscript.StdOut.WriteLine vbTab & "node list         list of MSCS node names to be monitored"
	Wscript.StdOut.WriteLine ""
	Wscript.StdOut.WriteLine "List items are comma separated."
	Wscript.StdOut.WriteLine ""
	WScript.Quit(0)
End if

If objArgs.Count < 2 Then
	Wscript.StdOut.WriteLine "CRITICAL - Bad number of arguments"
	WScript.Quit(2)
End if

for i = 1 to objArgs.Count - 1
	If i = 1 Then
		strArglist = objArgs(i)
	Else
		strArglist = strArglist + " " + objArgs(i)
	End If
next

Set objWMIService = GetObject("winmgmts:{impersonationLevel=impersonate}!\\.\root\mscluster")

Select Case objArgs(0)

	Case "RES"
		arrResNames = Split(strArglist, ",")
		For Each strResName in arrResNames
			strWmiQuery = "Select * from MSCluster_Resource WHERE Name = '" + strResName + "'"
			Set colItems = objWMIService.ExecQuery(strWmiQuery)
			strStatus = "unknown"
			For Each objItem in colItems
				Select Case objItem.State
					Case 2 strStatus = "online"
					Case 3 strStatus = "offline"
					Case 4 strStatus = "failed"
					Case 129 strStatus = "online pending"
					Case 130 strStatus = "offline pending"
				End Select
			Next
			If strStatus = "online" Then
				If strResultOK = "" Then
					strResultOK = strResName
				Else
					strResultOK = strResultOK + "," + strResName 
				End If
			Else
				strResultCritical = strResultCritical + strResName + " (" + strStatus + "), "
			End If
		Next

		If strResultCritical = "" Then
			Wscript.StdOut.WriteLine "OK - " + strResultOK
			WScript.Quit(0)
		Else
			Wscript.StdOut.WriteLine "CRITICAL - " + strResultCritical + "OK - " + strResultOK
			WScript.Quit(2)
		End If

	Case "NODE"
		arrNodeNames = Split(strArglist, ",")
		For Each strNodeName in arrNodeNames
			strWmiQuery = "Select * from MSCluster_Node WHERE Name = '" + strNodeName + "'"
			Set colItems = objWMIService.ExecQuery(strWmiQuery)
			strStatus = "unknown"
			For Each objItem in colItems
			' wscript.echo objItem.Name & vbTab & objItem.State
				Select Case objItem.State
					Case 0 strStatus = "up"
					Case 1 strStatus = "down"
					Case 2 strStatus = "paused"
					Case 3 strStatus = "joining"
					Case Else strStatus = "unknown"
				End Select
			Next
			If strStatus = "up" Then
				If strResultOK = "" Then
					strResultOK = strNodeName
				Else
					strResultOK = strResultOK + "," + strNodeName
				End If
			End If
			If strStatus = "paused" or strStatus = "joining" Then
				strResultWarning = strResultWarning + strNodeName + " (" + strStatus + "), "
			End If
			If strStatus = "down" or strStatus = "unknown" Then
				strResultCritical = strResultCritical + strNodeName + " (" + strStatus + "), "
			End If
		Next

		If strResultWarning = "" and strResultCritical = "" Then
			Wscript.StdOut.WriteLine "OK - " + strResultOK
			WScript.Quit(0)
		End If
		If strResultCritical = "" and strResultOK > "" Then
			Wscript.StdOut.WriteLine "WARNING - " + strResultWarning + "UP - " + strResultOK
			WScript.Quit(1)
		Else
			If strResultOK = "" Then
				strResultOK = "NONE !!!"
			End If
			Wscript.StdOut.WriteLine "CRITICAL - " + strResultCritical + strResultWarning + "UP - " + strResultOK
			WScript.Quit(2)
		End If
		
End Select

